@@ -1,13 +1,11 @@
-import csv
-import sys
-from pathlib import Path
-
 import sys
 from pathlib import Path
 
 import click
 
-from bridgebots import build_lin_str, build_lin_url
+from bridgebots import build_lin_str
+from bridgebots_tools.csv_report import _extract_team_dicts
+from bridgebots_tools.csv_utilities import _get_headers, _write_results
 from bridgebots_tools.data_extractors import _parse_results_file
 from bridgebots_tools.tools_logging import configure_logging
 
@@ -40,37 +38,27 @@ def report(
     configure_logging(log_level)
     input_path = next(input_dir.rglob(file_name))
 
-    csv_dict = {"board_id": board, "file": input_path.name}
     deal_records = _parse_results_file(input_path, input_format)
+    csv_dicts = []
     for deal_record in deal_records:
-        for board_record in deal_record.board_records:
+        if "o" + board in [board_record.board_name for board_record in deal_record.board_records]:
             # Write one instance of the board to the LIN file (or stdout)
-            if board_record.board_name in ["o" + board]:
-                lin_output = build_lin_str(deal_record.deal, board_record, lin_type="multi")
-                output_handle = open(output_lin, "a") if output_lin else sys.stdout
-                try:
-                    output_handle.write(lin_output + "\n")
-                finally:
-                    if output_lin:
-                        output_handle.close()
-            # Add both LIN links to the CSV dict
-            if board_record.board_name in ["c" + board, "o" + board]:
-                lin_url = build_lin_url(deal_record.deal, board_record)
-                link_key = "c_link" if board_record.board_name.startswith("c") else "o_link"
-                csv_dict[link_key] = lin_url
+            board_record = deal_record.board_records[0]
+            lin_output = build_lin_str(deal_record.deal, board_record, lin_type="multi")
+            output_handle = open(output_lin, "a") if output_lin else sys.stdout
+            try:
+                output_handle.write(lin_output + "\n")
+            finally:
+                if output_lin:
+                    output_handle.close()
+            # Now collect CSV information from the open and closed rooms
+            open_dict, closed_dict = _extract_team_dicts(deal_record, input_path)
+            prefix_dict = {f"o_{key}": value for key, value in open_dict.items()}
+            prefix_dict.update({f"c_{key}": value for key, value in closed_dict.items()})
+            csv_dicts.append(prefix_dict)
 
     # Write CSV to file (or stdout)
-    output_csv_exists = output_csv is not None and output_csv.exists()
-    output_handle = open(output_csv, "a") if output_csv else sys.stdout
-    try:
-        writer = csv.DictWriter(output_handle, fieldnames=_LINKS_CSV_HEADERS, extrasaction="ignore")
-        if not output_csv_exists:
-            writer.writeheader()
-        writer.writerow(csv_dict)
-
-    finally:
-        if output_csv:
-            output_handle.close()
+    _write_results(output_csv, csv_dicts, _get_headers(output_format="team"))
 
 
 if __name__ == "__main__":
